@@ -49,6 +49,10 @@ class EDAReport(Base,TransformerMixin):
     def fit(self, X, y=None):
 
         self._check_X(X)
+        
+        if X.select_dtypes(exclude=['number','object','category']).shape[1]>0:
+            
+            warnings.warn("column which not in ['number','object','category'] will not be shown in report")
 
         #产生报告
         self.num_report=self._num_info(X)
@@ -78,9 +82,12 @@ class EDAReport(Base,TransformerMixin):
         """
         
         if self.numeric_col is None:
-            num_col=X.select_dtypes(include='number').columns
+            
+            num_col=X.select_dtypes(include='number').columns.tolist()
+            
         else:
-            num_col=self.num_col
+            
+            num_col=self.numeric_col
 
         report=X[num_col].describe(percentiles=[0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9]).T.assign(
             MissingRate=X.apply(   
@@ -96,29 +103,38 @@ class EDAReport(Base,TransformerMixin):
         """
         
         if self.categorical_col is None:
-            category_col=X.select_dtypes(include=['object','category']).columns
+            
+            category_col=X.select_dtypes(include=['object','category']).columns.tolist()
+            
         else:
-            category_col=self.category_col
+            
+            category_col=self.categorical_col
     
-        report=pd.DataFrame()
-        for Col in category_col:
+        report={}
+        for col in category_col:
 
-            ColTable=X[Col].value_counts().sort_index().rename('Freq').reset_index() \
-                .rename(columns={'index':'Levels'}).assign(VarName=Col)[['VarName','Levels','Freq']]
+            ColTable=X[col].value_counts().sort_index().rename('Freq').reset_index() \
+                .rename(columns={'index':'Levels'})[['Levels','Freq']]
 
-            ColTable['Percent']=ColTable.Freq/X[Col].size #占比
+            ColTable['Percent']=ColTable.Freq/X[col].size #占比
             ColTable['CumFreq']=ColTable.Freq.cumsum() #累计(分类特征类别有次序性时有参考价值)
-            ColTable['CumPercent']=ColTable.CumFreq/X[Col].size #累计占比(分类特征类别有次序性时有参考价值)
+            ColTable['CumPercent']=ColTable.CumFreq/X[col].size #累计占比(分类特征类别有次序性时有参考价值)
 
-            report=pd.concat([report,ColTable])
+            report[col]=ColTable
         
-        return report
+        return pd.concat(report).droplevel(1).reset_index().rename(columns={'index':'Name'})
     
    
     def _nan_info(self,X):
         """ 数据质量报告-缺失特征
         """        
+                   
+        category_col=X.select_dtypes(include=['object','category']).columns.tolist() if self.categorical_col is None else self.categorical_col
+            
+        numeric_col=X.select_dtypes(include='number').columns.tolist() if self.numeric_col is None else self.numeric_col
         
+        X=X[set(category_col+numeric_col)].copy()
+ 
         report=pd.DataFrame(
         {'N':X.apply(   
             lambda col:col.size      
@@ -138,9 +154,17 @@ class EDAReport(Base,TransformerMixin):
     def _nan_corr(self,X):
         """ 数据质量报告-缺失特征相关性
         """        
+        
+        category_col=X.select_dtypes(include=['object','category']).columns.tolist() if self.categorical_col is None else self.categorical_col
+            
+        numeric_col=X.select_dtypes(include='number').columns.tolist() if self.numeric_col is None else self.numeric_col
+        
+        X=X[set(category_col+numeric_col)].copy()
       
         nan_info=X.isnull().sum()
+        
         nan_corr_table=X[nan_info[nan_info>0].index].isnull().corr()
+        
         return nan_corr_table
     
     def _writeExcel(self):
@@ -610,7 +634,7 @@ class varGroupsReport(Base,TransformerMixin,BaseWoePlotter):
     row_limit,int,分组行数限制，建议设定该参数至合理水平
         + 默认每组最少1000行，小于限制的组不统计其任何指标，返回空，
         + 当数据中存在组样本过少时，分组进行统计的bin可能会在某些分段内缺失导致concat时出现index overlapping错误，此时可适当提高row_limit以避免此类错误
-    special_values:缺失值指代值
+    special_values:特殊值指代值
             + None,保持数据默认
             + list=[value1,value2,...],数据中所有列的值在[value1,value2,...]中都会被替换，字符被替换为'missing',数值被替换为np.nan
             + dict={col_name1:[value1,value2,...],...},数据中指定列替换，被指定的列的值在[value1,value2,...]中都会被替换，字符被替换为'missing',数值被替换为np.nan  
