@@ -1,3 +1,11 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+"""
+Created on Tue Feb 22 17:03:34 2022
+
+@author: zengke
+"""
+
 from sklearn.base import BaseEstimator
 
 class RFECVSelector(BaseEstimator):
@@ -14,10 +22,4 @@ class RFECVSelector(BaseEstimator):
           
     def fit(self,X,y):
 
-        return self       
-
-
-
-
-
-    
\ No newline at end of file
+        return self       
\ No newline at end of file
